@@ -4,7 +4,7 @@
 # utils.h
 #
 # Written by Carter T. Butts <buttsc@uci.edu>
-# Last Modified 04/05/13
+# Last Modified 08/20/13
 # Licensed under the GNU General Public License version 2 (June, 1991)
 #
 # Part of the R/network package
@@ -32,11 +32,6 @@
 #define MAX(a,b) ((a)<(b) ? (b) : (a))
 
 
-/*ERROR ROUTINES-----------------------------------------------------------*/
-
-void SN_UNIMPLEMENTED_TYPE(const char *s, SEXPTYPE t);
-
-
 /*LIST ACCESS/MODIFICATION ROUTINES-----------------------------------------*/
 
 SEXP deleteListElement(SEXP list, const char *str);
